﻿using Microsoft.Practices.ServiceLocation;
using Microsoft.Practices.Unity;
using ModuleB;
using Prism.Events;
using Prism.Modularity;
using Prism.Regions;
using RadDockingAndPRISM.Events;
using RadDockingAndPRISM.Menu;
using System.ComponentModel.Composition;
using System.Linq;
using Telerik.Windows.Controls;

namespace RadDockingAndPRISM
{
    [Export]
    public class FileServicesModule : IModule
    {
        private readonly IRegionManager _regionManager;
        private readonly IUnityContainer _container;
        private IEventAggregator aggregator;

        [ImportingConstructor]
        public FileServicesModule(IRegionManager regionManager, IUnityContainer container, IEventAggregator aggregator)
        {
            this._regionManager = regionManager;
            this._container = container;
            this.aggregator = aggregator;
            aggregator.GetEvent<ActivateViewEvent>().Subscribe(this.OnActivateView, ThreadOption.PublisherThread, true);
        }

        private void OnActivateView(string obj)
        {
            var regionManager = ServiceLocator.Current.GetInstance<IRegionManager>();
            if (regionManager != null)
            {
                var dockRegion = regionManager.Regions["DockingView"];

                var dockingView = dockRegion.Views.FirstOrDefault();

                if (dockingView is DockingView)
                {
                    var docking = (dockingView as DockingView).ChildrenOfType<RadDocking>().FirstOrDefault();

                    if (docking != null)
                    {
                        var pane = docking.Panes.Where(a => a.Header.Equals(obj)).FirstOrDefault();

                        if (pane != null)
                        {
                            pane.IsHidden = pane.IsHidden ? false : true;
                        }
                    }
                }
            }
        }

        public void Initialize()
        {
            this.RegisterViews();
        }

        private void RegisterViews()
        {
            //this._regionManager.RegisterViewWithRegion("FileMenuRegion", typeof(ActivateViewA));
            this._regionManager.RegisterViewWithRegion("FileMenuRegion", typeof(ActivateViewB));
            this._regionManager.RegisterViewWithRegion("FileMenuRegion", typeof(ActivateViewB2));
        }
    }
}
